#[repr(u8)]pub enum ScrollHint {
TopLeft = 0,
BottomRight = 1,
TopEdge = 2,
BottomEdge = 3,
LeftEdge = 4,
RightEdge = 5,
}Expand description
A suggestion about where the node being scrolled into view should be positioned relative to the edges of the scrollable container.
Variants