#[repr(C)]pub struct Vec2 {
pub x: f64,
pub y: f64,
}Expand description
A 2D vector. Derived from kurbo.
This is intended primarily for a vector in the mathematical sense, but it can be interpreted as a translation, and converted to and from a point (vector relative to the origin) and size.
Fields
x: f64The x-coordinate.
y: f64The y-coordinate.
Implementations