pub struct CostLine { /* private fields */ }Expand description
One line of a CostMeter.
Implementations
Sourceimpl CostLine
impl CostLine
pub fn new( id: impl Into<SharedString>, label: impl Into<SharedString>, reading: Reading, ) -> Self
Sourcepub fn stale(self, verified: LastVerified) -> Self
pub fn stale(self, verified: LastVerified) -> Self
The refresh that should have replaced this reading did not. The value stays on screen and says when it was from.
pub fn id(&self) -> &SharedString
pub fn reading(&self) -> &Reading