Module offering_catalog

Module offering_catalog 

Searchable offerings aggregated across caller-owned server sources.

This component displays what callers already know. It does not discover, install, invoke, trust, permit, or connect to anything. A result is always identified by both its server and offering because names and offering ids are only unique within one server.

Structs

OfferingCatalog
A searchable, kind-filterable catalog of offerings from multiple servers.
OfferingIdentity
Stable identity for one server-owned offering.
OfferingSource
One attributed source and its independently truthful state.
SearchableOffering
An offering and the caller-authored text used to search it.

Enums

OfferingSourceState
What is truthfully known about one source’s offerings.