pub struct GraphEndpoint {
pub node: SharedString,
pub port: SharedString,
}Expand description
A caller-owned node and port identity used by connection proposals.
Fields
node: SharedStringport: SharedStringImplementations
Sourceimpl GraphEndpoint
impl GraphEndpoint
Sourcepub fn new(node: impl Into<SharedString>, port: impl Into<SharedString>) -> Self
pub fn new(node: impl Into<SharedString>, port: impl Into<SharedString>) -> Self
Creates an endpoint from business identities, not display labels.