pub struct DiffView { /* private fields */ }Expand description
A virtualized, read-only diff presentation.
Implementations
Sourceimpl DiffView
impl DiffView
pub fn new( ident: impl Into<Ident>, files: impl IntoIterator<Item = DiffFile>, ) -> Self
pub fn presentation(self, presentation: DiffPresentation) -> Self
Sourcepub fn visible_rows(self, rows: usize) -> Self
pub fn visible_rows(self, rows: usize) -> Self
Bounds and virtualizes the view to this many fixed-height rows. File and hunk headers each occupy one row too.