pub struct ImageRequest {
pub id: SharedString,
pub label: SharedString,
pub source: SharedString,
pub natural: Option<ImageSize>,
}Expand description
An image the viewer had to draw and the host has not supplied.
Fields
id: SharedStringlabel: SharedStringsource: SharedStringnatural: Option<ImageSize>What the host said the source measures, when it said anything.