pub struct PasswordInput { /* private fields */ }Expand description
One sensitive password editor with a visual reveal action.
Revealing changes only the pixels. The value remains a secret for deterministic semantics, AccessKit text runs and values, Debug, and clipboard copy/cut.
Implementations
Sourceimpl PasswordInput
impl PasswordInput
pub fn new( ident: impl Into<Ident>, window: &mut Window, cx: &mut Context<'_, Self>, ) -> Self
pub fn placeholder(self, placeholder: impl Into<SharedString>) -> Self
Sourcepub fn name(self, name: impl Into<SharedString>) -> Self
pub fn name(self, name: impl Into<SharedString>) -> Self
Names the one native password input when its visible label is outside this view.
Sourcepub fn text(self, text: impl Into<SharedString>) -> Self
pub fn text(self, text: impl Into<SharedString>) -> Self
Seeds the sensitive text without reporting a caller edit.
pub fn invalid(self, invalid: bool) -> Self
pub fn required(self, required: bool) -> Self
pub fn read_only(self, read_only: bool) -> Self
pub fn value(&self, cx: &App) -> SharedString
pub fn is_revealed(&self) -> bool
pub fn selected_range(&self, cx: &App) -> Range<usize> ⓘ
pub fn set_value( &mut self, value: impl Into<SharedString>, cx: &mut Context<'_, Self>, )
pub fn set_disabled(&mut self, disabled: bool, cx: &mut Context<'_, Self>)
pub fn set_read_only(&mut self, read_only: bool, cx: &mut Context<'_, Self>)
pub fn set_invalid(&mut self, invalid: bool, cx: &mut Context<'_, Self>)