pub struct Cell { /* private fields */ }Expand description
One cell’s content, and whether it is an assertion target.
Implementations
Sourceimpl Cell
impl Cell
pub fn new(content: impl IntoElement) -> Self
Sourcepub fn text(self, text: impl Into<SharedString>) -> Self
pub fn text(self, text: impl Into<SharedString>) -> Self
The name the cell publishes when it is published.
Sourcepub fn published(self, published: bool) -> Self
pub fn published(self, published: bool) -> Self
Publishes a Role::Cell node at <row id>.<column key>.