pub fn flips(glyph: Icon, direction: LayoutDirection) -> boolExpand description
Whether glyph should be drawn flipped when the interface reads
direction.
pub fn flips(glyph: Icon, direction: LayoutDirection) -> boolWhether glyph should be drawn flipped when the interface reads
direction.