pub struct SparklineReading {
pub points: Vec<SparklinePoint>,
pub current: SharedString,
pub minimum: SharedString,
pub maximum: SharedString,
}Expand description
The plotted points and the exact text that makes them accessible.
Fields
points: Vec<SparklinePoint>current: SharedStringminimum: SharedStringmaximum: SharedStringImplementations
Sourceimpl SparklineReading
impl SparklineReading
pub fn new( points: impl IntoIterator<Item = SparklinePoint>, current: impl Into<SharedString>, minimum: impl Into<SharedString>, maximum: impl Into<SharedString>, ) -> Self
Sourcepub fn published_points(&self) -> usize
pub fn published_points(&self) -> usize
How many supplied points are inside the documented normalized bounds.