pub enum WindowingRequest {
Headless,
Windowed(GraphicalEnvironment),
}Expand description
A display mode for App::request_windowing to switch to.
Variants
Headless
No display server. Windows lay out and handle input but draw nothing.
Windowed(GraphicalEnvironment)
Connected to the display server that the environment names.