pub trait Disableable {
// Required method
fn disabled(self, disabled: bool) -> Self;
}Expand description
A control that can refuse interaction.
Implementations must not install action handlers while disabled, so a disabled control cannot fire even if a host mis-routes an event.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".