Module layer_shell
gpui_
kit
0.6.0
Module layer_
shell
Module Items
Structs
Enums
In crate gpui_
kit
gpui_kit
Module
layer_
shell
Structs

Anchor
Screen anchor point for layer_shell surfaces. These can be used in any combination, e.g. specifying
Anchor::LEFT | Anchor::RIGHT
will stretch the surface across the width of the screen.
Layer
Shell
NotSupported
Error
An error indicating that an action failed because the compositor doesn’t support the required layer_shell protocol.
Layer
Shell
Options
Options for creating a layer_shell window.
Enums

Keyboard
Interactivity
Keyboard interactivity mode for the layer_shell surfaces.
Layer
The layer the surface is rendered on. Multiple surfaces can share a layer, and ordering within a single layer is undefined.