pub enum SplitSide {
Start,
End,
}Expand description
One of the two panes.
Variants
Start
Left in a horizontal split, top in a vertical one.
End
Right in a horizontal split, bottom in a vertical one.
Implementations