dialog_arrival

Function dialog_arrival 

pub fn dialog_arrival(theme: &Theme) -> MotionSpec
How a modal arrives when it should arrive with weight: on the smooth spring, which keeps moving after a curve of the same length has stopped.