pub fn resize(theme: &Theme) -> MotionSpecExpand description
How a value that has a position moves to a new one, such as a progress fill or an opening section.
pub fn resize(theme: &Theme) -> MotionSpecHow a value that has a position moves to a new one, such as a progress fill or an opening section.