staggered_phase

Function staggered_phase 

pub fn staggered_phase(raw: f32, index: usize, stagger: f32) -> f32
The repeating phase for item index in a looping group animation, such as a chase or wave loader.