pub fn state_change(theme: &Theme) -> MotionSpecExpand description
How one control moves to a new state: short, because it is answering a pointer that is still on it.
pub fn state_change(theme: &Theme) -> MotionSpecHow one control moves to a new state: short, because it is answering a pointer that is still on it.