pub enum Edge {
Left,
Right,
Top,
Bottom,
}Expand description
One side of the window.
Variants
Implementations
Sourceimpl Edge
impl Edge
Sourcepub fn is_horizontal(self) -> bool
pub fn is_horizontal(self) -> bool
True when the surface stretches vertically and is pinned horizontally.
Sourcepub fn is_leading(self) -> bool
pub fn is_leading(self) -> bool
True when the surface hangs off the low end of its axis.