pub struct SerializedTaskTiming {
pub location: SerializedLocation,
pub start: u128,
pub duration: u128,
}Expand description
Serializable variant of [TaskTiming]
Fields
location: SerializedLocationLocation of the timing
start: u128Time at which the measurement was reported in nanoseconds
duration: u128Duration of the measurement in nanoseconds
Implementations
Sourceimpl SerializedTaskTiming
impl SerializedTaskTiming
Sourcepub fn convert(
anchor: Instant,
timings: &[TaskTiming],
) -> Vec<SerializedTaskTiming>
pub fn convert( anchor: Instant, timings: &[TaskTiming], ) -> Vec<SerializedTaskTiming>
Sourcepub fn from(anchor: Instant, timing: TaskTiming) -> SerializedTaskTiming
pub fn from(anchor: Instant, timing: TaskTiming) -> SerializedTaskTiming
anchor - Instant that should be earlier than all timings to use as base anchor