Module state

Module state 

Explicit async states for truthful user interfaces.

Structs

AsyncValue
A value and, separately, what is currently happening to it.

Enums

AsyncStatus
What is happening to an AsyncValue right now.
Loadable
The states a value a host is fetching can be in.