pub struct AnimationPhase(pub f32);Expand description
A potentially overshooting coordinate within an animation.
Phases are not restricted to 0..1. Multi-stage animations can assign each stage its own coordinate and interpolate over ranges such as 1..=2.
Tuple Fields
0: f32The unbounded phase coordinate.
Implementations
Sourceimpl AnimationPhase
impl AnimationPhase
Sourcepub fn clamp(self, range: RangeInclusive<f32>) -> AnimationPhase
pub fn clamp(self, range: RangeInclusive<f32>) -> AnimationPhase
Restricts this phase to the bounds of a range.
Sourcepub fn interpolate<T>(self, from: T, to: T) -> Twhere
T: Interpolate,
pub fn interpolate<T>(self, from: T, to: T) -> Twhere
T: Interpolate,
Interpolates between values using 0 and 1 as their phase coordinates.
Sourcepub fn interpolate_clamped<T>(self, from: T, to: T) -> Twhere
T: Interpolate,
pub fn interpolate_clamped<T>(self, from: T, to: T) -> Twhere
T: Interpolate,
Interpolates between values without extrapolating beyond 0 and 1.
Sourcepub fn interpolate_between<T>(
self,
range: RangeInclusive<f32>,
from: T,
to: T,
) -> Twhere
T: Interpolate,
pub fn interpolate_between<T>(
self,
range: RangeInclusive<f32>,
from: T,
to: T,
) -> Twhere
T: Interpolate,
Interpolates between values assigned to arbitrary phase coordinates.
Sourcepub fn interpolate_between_clamped<T>(
self,
range: RangeInclusive<f32>,
from: T,
to: T,
) -> Twhere
T: Interpolate,
pub fn interpolate_between_clamped<T>(
self,
range: RangeInclusive<f32>,
from: T,
to: T,
) -> Twhere
T: Interpolate,
Interpolates over arbitrary phase coordinates without extrapolating.