pub struct Entity<T> { /* private fields */ }Expand description
A strong, well-typed reference to a struct which is managed by GPUI
Implementations
Sourceimpl<T> Entity<T>where
T: 'static,
impl<T> Entity<T>where
T: 'static,
Sourcepub fn downgrade(&self) -> WeakEntity<T>
pub fn downgrade(&self) -> WeakEntity<T>
Downgrade this entity pointer to a non-retaining weak pointer
Sourcepub fn read_with<R, C>(&self, cx: &C, f: impl FnOnce(&T, &App) -> R) -> Rwhere
C: AppContext,
pub fn read_with<R, C>(&self, cx: &C, f: impl FnOnce(&T, &App) -> R) -> Rwhere
C: AppContext,
Read the entity referenced by this handle with the given function.
Sourcepub fn update<R, C>(
&self,
cx: &mut C,
update: impl FnOnce(&mut T, &mut Context<'_, T>) -> R,
) -> Rwhere
C: AppContext,
pub fn update<R, C>(
&self,
cx: &mut C,
update: impl FnOnce(&mut T, &mut Context<'_, T>) -> R,
) -> Rwhere
C: AppContext,
Updates the entity referenced by this handle with the given function.
Sourcepub fn as_mut<'a, C>(&self, cx: &'a mut C) -> GpuiBorrow<'a, T>where
C: AppContext,
pub fn as_mut<'a, C>(&self, cx: &'a mut C) -> GpuiBorrow<'a, T>where
C: AppContext,
Updates the entity referenced by this handle with the given function.
Sourcepub fn write<C>(&self, cx: &mut C, value: T)where
C: AppContext,
pub fn write<C>(&self, cx: &mut C, value: T)where
C: AppContext,
Updates the entity referenced by this handle with the given function.
Sourcepub fn update_in<R, C>(
&self,
cx: &mut C,
update: impl FnOnce(&mut T, &mut Window, &mut Context<'_, T>) -> R,
) -> <C as VisualContext>::Result<R>where
C: VisualContext,
pub fn update_in<R, C>(
&self,
cx: &mut C,
update: impl FnOnce(&mut T, &mut Window, &mut Context<'_, T>) -> R,
) -> <C as VisualContext>::Result<R>where
C: VisualContext,
Updates the entity referenced by this handle with the given function if the referenced entity still exists, within a visual context that has a window. Returns an error if the window has been closed.
Sourceimpl<T> Entity<T>where
T: Render,
impl<T> Entity<T>where
T: Render,
Sourcepub fn cached(self, style: StyleRefinement) -> ViewElement<Entity<T>>
pub fn cached(self, style: StyleRefinement) -> ViewElement<Entity<T>>
Embed this entity as a cached [ViewElement] laid out at style.
The rendered subtree is reused until the entity is notified (or the
cached bounds / text style change). Caching requires a definite size:
a cached view is laid out from style and is not measured from its
contents. Use [ViewElement::new] (or .child(entity)) for the
uncached case.
Methods from Deref<Target = AnyEntity>
Sourcepub fn entity_type(&self) -> TypeId
pub fn entity_type(&self) -> TypeId
Returns the TypeId associated with this entity.
Sourcepub fn downgrade(&self) -> AnyWeakEntity
pub fn downgrade(&self) -> AnyWeakEntity
Converts this entity handle into a weak variant, which does not prevent it from being released.