pub struct FileDragPaths(/* private fields */);Expand description
Paths handed to the platform for a native file drag. Directory metadata is provided by the caller to avoid querying it when the platform drag starts.
Implementations
Sourceimpl FileDragPaths
impl FileDragPaths
Sourcepub fn new(entries: impl IntoIterator<Item = (PathBuf, bool)>) -> FileDragPaths
pub fn new(entries: impl IntoIterator<Item = (PathBuf, bool)>) -> FileDragPaths
Creates a native file-drag payload from paths paired with whether each path is a directory.