pub struct Subscription { /* private fields */ }Expand description
A handle to a subscription created by GPUI. When dropped, the subscription is cancelled and the callback will no longer be invoked.
Implementations
Sourceimpl Subscription
impl Subscription
Sourcepub fn new(unsubscribe: impl FnOnce() + 'static) -> Subscription
pub fn new(unsubscribe: impl FnOnce() + 'static) -> Subscription
Creates a new subscription with a callback that gets invoked when this subscription is dropped.
Sourcepub fn detach(self)
pub fn detach(self)
Detaches the subscription from this handle. The callback will continue to be invoked until the entities it has been subscribed to are dropped
Sourcepub fn join(
subscription_a: Subscription,
subscription_b: Subscription,
) -> Subscription
pub fn join( subscription_a: Subscription, subscription_b: Subscription, ) -> Subscription
Joins two subscriptions into a single subscription. Detach will detach both interior subscriptions.