pub struct TouchId(pub u64);Expand description
Identifies one touch (finger or stylus contact) for its lifetime, from
TouchPhase::Started through TouchPhase::Ended or
TouchPhase::Cancelled.
The value is opaque and assigned by the platform. A platform window must not reuse an identifier for a later touch.
Tuple Fields
0: u64Trait Implementations
impl Copy for TouchId
impl Eq for TouchId
Sourceimpl Ord for TouchId
impl Ord for TouchId
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for TouchId
impl PartialOrd for TouchId
impl StructuralPartialEq for TouchId