pub struct WeakEntity<T> { /* private fields */ }Expand description
A weak reference to a entity of the given type.
Implementations
Sourceimpl<T> WeakEntity<T>where
T: 'static,
impl<T> WeakEntity<T>where
T: 'static,
Sourcepub fn upgrade(&self) -> Option<Entity<T>>
pub fn upgrade(&self) -> Option<Entity<T>>
Upgrade this weak entity reference into a strong entity reference
Sourcepub fn update<C, R>(
&self,
cx: &mut C,
update: impl FnOnce(&mut T, &mut Context<'_, T>) -> R,
) -> Result<R, Error>where
C: AppContext,
pub fn update<C, R>(
&self,
cx: &mut C,
update: impl FnOnce(&mut T, &mut Context<'_, T>) -> R,
) -> Result<R, Error>where
C: AppContext,
Updates the entity referenced by this handle with the given function if the referenced entity still exists. Returns an error if the entity has been released.
Sourcepub fn update_in<C, R>(
&self,
cx: &mut C,
update: impl FnOnce(&mut T, &mut Window, &mut Context<'_, T>) -> R,
) -> Result<R, Error>where
C: AppContext,
pub fn update_in<C, R>(
&self,
cx: &mut C,
update: impl FnOnce(&mut T, &mut Window, &mut Context<'_, T>) -> R,
) -> Result<R, Error>where
C: AppContext,
Updates the entity referenced by this handle with the given function if the referenced entity still exists, within a visual context that has a window. Returns an error if the entity has been released.
Sourcepub fn read_with<C, R>(
&self,
cx: &C,
read: impl FnOnce(&T, &App) -> R,
) -> Result<R, Error>where
C: AppContext,
pub fn read_with<C, R>(
&self,
cx: &C,
read: impl FnOnce(&T, &App) -> R,
) -> Result<R, Error>where
C: AppContext,
Reads the entity referenced by this handle with the given function if the referenced entity still exists. Returns an error if the entity has been released.
Sourcepub fn new_invalid() -> WeakEntity<T>
pub fn new_invalid() -> WeakEntity<T>
Create a new weak entity that can never be upgraded.
Methods from Deref<Target = AnyWeakEntity>
Sourcepub fn is_upgradable(&self) -> bool
pub fn is_upgradable(&self) -> bool
Check if this weak handle can be upgraded, or if the entity has already been dropped