pub struct WindowHandle<V> { /* private fields */ }Expand description
A handle to a window with a specific root view type. Note that this does not keep the window alive on its own.
Implementations
Sourceimpl<V> WindowHandle<V>where
V: 'static + Render,
impl<V> WindowHandle<V>where
V: 'static + Render,
Sourcepub fn new(id: WindowId) -> WindowHandle<V>
pub fn new(id: WindowId) -> WindowHandle<V>
Creates a new handle from a window ID.
This does not check if the root type of the window is V.
Sourcepub fn update<C, R>(
&self,
cx: &mut C,
update: impl FnOnce(&mut V, &mut Window, &mut Context<'_, V>) -> R,
) -> Result<R, Error>where
C: AppContext,
pub fn update<C, R>(
&self,
cx: &mut C,
update: impl FnOnce(&mut V, &mut Window, &mut Context<'_, V>) -> R,
) -> Result<R, Error>where
C: AppContext,
Updates the root view of this window.
This will fail if the window has been closed or if the root view’s type does not match
Sourcepub fn read<'a>(&self, cx: &'a App) -> Result<&'a V, Error>
pub fn read<'a>(&self, cx: &'a App) -> Result<&'a V, Error>
Read the root view out of this window.
This will fail if the window is closed or if the root view’s type does not match V.
Sourcepub fn read_with<C, R>(
&self,
cx: &C,
read_with: impl FnOnce(&V, &App) -> R,
) -> Result<R, Error>where
C: AppContext,
pub fn read_with<C, R>(
&self,
cx: &C,
read_with: impl FnOnce(&V, &App) -> R,
) -> Result<R, Error>where
C: AppContext,
Read the root view out of this window, with a callback
This will fail if the window is closed or if the root view’s type does not match V.
Methods from Deref<Target = AnyWindowHandle>
Sourcepub fn root_entity_type_name(&self) -> &'static str
pub fn root_entity_type_name(&self) -> &'static str
Returns the name of the window’s declared root entity type.
Sourcepub fn downcast<T>(&self) -> Option<WindowHandle<T>>where
T: 'static,
pub fn downcast<T>(&self) -> Option<WindowHandle<T>>where
T: 'static,
Attempt to convert this handle to a window handle with a specific root view type.
If the types do not match, this will return None.