pub struct WindowParams {Show 13 fields
pub bounds: Bounds<Pixels>,
pub titlebar: Option<TitlebarOptions>,
pub kind: WindowKind,
pub is_movable: bool,
pub app_owns_titlebar_drag: bool,
pub is_resizable: bool,
pub is_minimizable: bool,
pub focus: bool,
pub show: bool,
pub icon: Option<Arc<ImageBuffer<Rgba<u8>, Vec<u8>>>>,
pub display_id: Option<DisplayId>,
pub app_id: Option<String>,
pub window_min_size: Option<Size<Pixels>>,
}Expand description
The variables that can be configured when creating a new window
Fields
bounds: Bounds<Pixels>titlebar: Option<TitlebarOptions>The titlebar configuration of the window
kind: WindowKindThe kind of window to create
is_movable: boolWhether the window should be movable by the user
app_owns_titlebar_drag: boolWhether the application owns dragging of the (custom) titlebar (macOS only)
is_resizable: boolWhether the window should be resizable by the user
is_minimizable: boolWhether the window should be minimized by the user
focus: boolshow: boolicon: Option<Arc<ImageBuffer<Rgba<u8>, Vec<u8>>>>An image to set as the window icon (x11 only)
display_id: Option<DisplayId>app_id: Option<String>window_min_size: Option<Size<Pixels>>Trait Implementations