Module styled_reflection
gpui_
kit
0.6.0
Module styled_
reflection
Module Items
Functions
In crate gpui_
kit
gpui_kit
Module
styled_
reflection
Implements function reflection
Functions

find_
method
Find a method by name for a concrete type implementing the trait
methods
Get all reflectable methods for a concrete type implementing the trait