pub fn find_method<T>(name: &str) -> Option<FunctionReflection<T>>where
T: Styled + 'static,Expand description
Find a method by name for a concrete type implementing the trait
pub fn find_method<T>(name: &str) -> Option<FunctionReflection<T>>where
T: Styled + 'static,Find a method by name for a concrete type implementing the trait