pub fn methods<T>() -> Vec<FunctionReflection<T>>where
T: Styled + 'static,Expand description
Get all reflectable methods for a concrete type implementing the trait
pub fn methods<T>() -> Vec<FunctionReflection<T>>where
T: Styled + 'static,Get all reflectable methods for a concrete type implementing the trait