IntoElement

Trait IntoElement 

pub trait IntoElement: Sized {
    type Element: Element;

    // Required method
    fn into_element(self) -> Self::Element;

    // Provided method
    fn into_any_element(self) -> AnyElement { ... }
}
Implemented by any type that can be converted into an element.

Required Associated Types

type Element: Element

The specific type of element into which the implementing type is converted. Useful for converting other types into elements automatically, like Strings

Required Methods

fn into_element(self) -> Self::Element

Convert self into a type that implements Element.

Provided Methods

fn into_any_element(self) -> AnyElement

Convert self into a dynamically-typed AnyElement.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IntoElement for &'static str

Source

type Element = &'static str

Source

fn into_element(self) -> <&'static str as IntoElement>::Element

Source

impl IntoElement for Accordion

Source

impl IntoElement for Accordion

Source

impl IntoElement for AccordionHeader

Source

impl IntoElement for AccordionItem

Source

impl IntoElement for AccordionItem

Source

impl IntoElement for AccordionPanel

Source

impl IntoElement for AccordionTrigger

Source

impl IntoElement for Alert

Source

type Element = ViewElement<Alert>

Source

fn into_element(self) -> <Alert as IntoElement>::Element

Source

impl IntoElement for AlertDialog

Source

impl IntoElement for AlertDialog

Source

impl IntoElement for AlertDialogAction

Source

impl IntoElement for AlertDialogBackdrop

Source

impl IntoElement for AlertDialogCancel

Source

impl IntoElement for AlertDialogClose

Source

impl IntoElement for AlertDialogDescription

Source

impl IntoElement for AlertDialogPopup

Source

impl IntoElement for AlertDialogTitle

Source

impl IntoElement for AlertDialogTrigger

Source

impl IntoElement for Attachment

Source

impl IntoElement for AttachmentActions

Source

impl IntoElement for AttachmentContent

Source

impl IntoElement for AttachmentDescription

Source

impl IntoElement for AttachmentGroup

Source

impl IntoElement for AttachmentMedia

Source

impl IntoElement for AttachmentTitle

Source

impl IntoElement for Avatar

Source

impl IntoElement for Avatar

Source

impl IntoElement for AvatarFallback

Source

impl IntoElement for AvatarGroup

Source

impl IntoElement for AvatarImage

Source

impl IntoElement for Badge

Source

type Element = ViewElement<Badge>

Source

fn into_element(self) -> <Badge as IntoElement>::Element

Source

impl IntoElement for Breadcrumb

Source

impl IntoElement for BreadcrumbItem

Source

impl IntoElement for Bubble

Source

impl IntoElement for BubbleContent

Source

impl IntoElement for BubbleGroup

Source

impl IntoElement for BubbleReactions

Source

impl IntoElement for Button

Source

impl IntoElement for Button

Source

impl IntoElement for ButtonGroup

Source

impl IntoElement for Calendar

Source

impl IntoElement for Calendar

Source

impl IntoElement for CalendarItem

Source

impl IntoElement for Caret

Source

type Element = ViewElement<Caret>

Source

fn into_element(self) -> <Caret as IntoElement>::Element

Source

impl IntoElement for Checkbox

Source

impl IntoElement for Checkbox

Source

impl IntoElement for CheckboxIndicator

Source

impl IntoElement for Clipboard

Source

impl IntoElement for Collapsible

Source

impl IntoElement for Collapsible

Source

impl IntoElement for ColorPicker

Source

impl IntoElement for ColorPicker

Source

impl IntoElement for ColorSwatch

Source

impl IntoElement for Combobox

Source

impl IntoElement for Command

Source

impl IntoElement for Cow<'static, str>

Source

impl IntoElement for CrossLine

Source

impl IntoElement for DatePicker

Source

impl IntoElement for DatePicker

Source

impl IntoElement for DescriptionList

Source

impl IntoElement for DescriptionText

Source

impl IntoElement for Dialog

Source

impl IntoElement for Dialog

Source

impl IntoElement for DialogAction

Source

impl IntoElement for DialogBackdrop

Source

impl IntoElement for DialogClose

Source

impl IntoElement for DialogClose

Source

impl IntoElement for DialogContent

Source

impl IntoElement for DialogDescription

Source

impl IntoElement for DialogDescription

Source

impl IntoElement for DialogFooter

Source

impl IntoElement for DialogHeader

Source

impl IntoElement for DialogPopup

Source

impl IntoElement for DialogTitle

Source

impl IntoElement for DialogTitle

Source

impl IntoElement for DialogTrigger

Source

impl IntoElement for Dot

Source

type Element = ViewElement<Dot>

Source

fn into_element(self) -> <Dot as IntoElement>::Element

Source

impl IntoElement for DropdownButton

Source

impl IntoElement for Editor

Source

impl IntoElement for Editor

Source

impl IntoElement for Field

Source

type Element = ViewElement<Field>

Source

fn into_element(self) -> <Field as IntoElement>::Element

Source

impl IntoElement for Form

Source

type Element = ViewElement<Form>

Source

fn into_element(self) -> <Form as IntoElement>::Element

Source

impl IntoElement for GroupBox

Source

impl IntoElement for HoverCard

Source

impl IntoElement for HoverCard

Source

impl IntoElement for Icon

Source

type Element = ViewElement<Icon>

Source

fn into_element(self) -> <Icon as IntoElement>::Element

Source

impl IntoElement for IconName

Source

impl IntoElement for Input

Source

type Element = ViewElement<Input>

Source

fn into_element(self) -> <Input as IntoElement>::Element

Source

impl IntoElement for Input

Source

type Element = ViewElement<Input>

Source

fn into_element(self) -> <Input as IntoElement>::Element

Source

impl IntoElement for InputBase

Source

impl IntoElement for Kbd

Source

type Element = ViewElement<Kbd>

Source

fn into_element(self) -> <Kbd as IntoElement>::Element

Source

impl IntoElement for Label

Source

type Element = ViewElement<Label>

Source

fn into_element(self) -> <Label as IntoElement>::Element

Source

type Element = ViewElement<Link>

Source

fn into_element(self) -> <Link as IntoElement>::Element

Source

type Element = ViewElement<Link>

Source

fn into_element(self) -> <Link as IntoElement>::Element

Source

impl IntoElement for ListItem

Source

impl IntoElement for Marker

Source

impl IntoElement for MarkerContent

Source

impl IntoElement for MarkerIcon

Source

impl IntoElement for Message

Source

impl IntoElement for MessageAvatar

Source

impl IntoElement for MessageContent

Source

impl IntoElement for MessageFooter

Source

impl IntoElement for MessageGroup

Source

impl IntoElement for MessageHeader

Source

impl IntoElement for MessageScroller

Source

impl IntoElement for MotionReveal

Source

impl IntoElement for NavPage

Source

impl IntoElement for NavStack

Source

impl IntoElement for NumberInput

Source

impl IntoElement for NumberInput

Source

impl IntoElement for NumberInputText

Source

impl IntoElement for OtpInput

Source

impl IntoElement for OtpInput

Source

impl IntoElement for Pagination

Source

impl IntoElement for Pagination

Source

impl IntoElement for Popover

Source

impl IntoElement for Popover

Source

impl IntoElement for Popup

Source

type Element = ViewElement<Popup>

Source

fn into_element(self) -> <Popup as IntoElement>::Element

Source

impl IntoElement for Positioner

Source

impl IntoElement for Progress

Source

impl IntoElement for Progress

Source

impl IntoElement for ProgressCircle

Source

impl IntoElement for ProgressIndicator

Source

impl IntoElement for ProgressTrack

Source

impl IntoElement for Radio

Source

type Element = ViewElement<Radio>

Source

fn into_element(self) -> <Radio as IntoElement>::Element

Source

impl IntoElement for Radio

Source

type Element = ViewElement<Radio>

Source

fn into_element(self) -> <Radio as IntoElement>::Element

Source

impl IntoElement for RadioGroup

Source

impl IntoElement for RadioGroup

Source

impl IntoElement for Rating

Source

impl IntoElement for ResizablePanel

Source

impl IntoElement for ResizablePanelGroup

Source

impl IntoElement for Scrollbar

Source

impl IntoElement for SearchableListItemElement

Source

impl IntoElement for Select

Source

impl IntoElement for SelectableText

Source

impl IntoElement for Separator

Source

impl IntoElement for Settings

Source

impl IntoElement for Sheet

Source

type Element = ViewElement<Sheet>

Source

fn into_element(self) -> <Sheet as IntoElement>::Element

Source

impl IntoElement for Sheet

Source

type Element = ViewElement<Sheet>

Source

fn into_element(self) -> <Sheet as IntoElement>::Element

Source

impl IntoElement for ShimmerText

Source

impl IntoElement for SidebarFooter

Source

impl IntoElement for SidebarHeader

Source

impl IntoElement for SidebarToggleButton

Source

impl IntoElement for Skeleton

Source

impl IntoElement for Slider

Source

impl IntoElement for Slider

Source

impl IntoElement for SliderIndicator

Source

impl IntoElement for SliderThumb

Source

impl IntoElement for SliderTrack

Source

impl IntoElement for Spinner

Source

impl IntoElement for StatusBar

Source

impl IntoElement for Stepper

Source

impl IntoElement for StepperItem

Source

impl IntoElement for String

Source

impl IntoElement for Switch

Source

impl IntoElement for Switch

Source

impl IntoElement for SwitchThumb

Source

impl IntoElement for SwitchTrack

Source

impl IntoElement for Tab

Source

type Element = ViewElement<Tab>

Source

fn into_element(self) -> <Tab as IntoElement>::Element

Source

impl IntoElement for Tab

Source

type Element = ViewElement<Tab>

Source

fn into_element(self) -> <Tab as IntoElement>::Element

Source

impl IntoElement for TabBar

Source

impl IntoElement for Table

Source

type Element = ViewElement<Table>

Source

fn into_element(self) -> <Table as IntoElement>::Element

Source

impl IntoElement for Table

Source

type Element = ViewElement<Table>

Source

fn into_element(self) -> <Table as IntoElement>::Element

Source

impl IntoElement for TableBody

Source

impl IntoElement for TableBody

Source

impl IntoElement for TableCaption

Source

impl IntoElement for TableCaption

Source

impl IntoElement for TableCell

Source

impl IntoElement for TableCell

Source

impl IntoElement for TableFooter

Source

impl IntoElement for TableHead

Source

impl IntoElement for TableHead

Source

impl IntoElement for TableHeader

Source

impl IntoElement for TableHeader

Source

impl IntoElement for TableRow

Source

impl IntoElement for TableRow

Source

impl IntoElement for Tabs

Source

type Element = ViewElement<Tabs>

Source

fn into_element(self) -> <Tabs as IntoElement>::Element

Source

impl IntoElement for Tag

Source

type Element = ViewElement<Tag>

Source

fn into_element(self) -> <Tag as IntoElement>::Element

Source

impl IntoElement for Text

Source

type Element = ViewElement<Text>

Source

fn into_element(self) -> <Text as IntoElement>::Element

Source

impl IntoElement for Text

Source

type Element = ViewElement<Text>

Source

fn into_element(self) -> <Text as IntoElement>::Element

Source

impl IntoElement for TextSelectionLayer

Source

impl IntoElement for TextView

Source

impl IntoElement for TextView

Source

impl IntoElement for Textarea

Source

impl IntoElement for Textarea

Source

impl IntoElement for TitleBar

Source

impl IntoElement for Toast

Source

type Element = ViewElement<Toast>

Source

fn into_element(self) -> <Toast as IntoElement>::Element

Source

impl IntoElement for ToastStack

Source

impl IntoElement for Toggle

Source

impl IntoElement for Toggle

Source

impl IntoElement for ToggleGroup

Source

impl IntoElement for ToggleGroup

Source

impl IntoElement for Tooltip

Source

impl IntoElement for Tooltip

Source

impl IntoElement for TooltipPositioner

Source

impl IntoElement for Tree

Source

type Element = ViewElement<Tree>

Source

fn into_element(self) -> <Tree as IntoElement>::Element

Source

impl IntoElement for Tree

Source

type Element = ViewElement<Tree>

Source

fn into_element(self) -> <Tree as IntoElement>::Element

Source

impl IntoElement for VirtualList

Source

impl IntoElement for WindowBorder

Source

impl<D> IntoElement for Combobox<D>

Source

type Element = ViewElement<Combobox<D>>

Source

fn into_element(self) -> <Combobox<D> as IntoElement>::Element

Source

impl<D> IntoElement for DataTable<D>
where D: TableDelegate,

Source

type Element = ViewElement<DataTable<D>>

Source

fn into_element(self) -> <DataTable<D> as IntoElement>::Element

Source

impl<D> IntoElement for List<D>
where D: ListDelegate + 'static,

Source

type Element = ViewElement<List<D>>

Source

fn into_element(self) -> <List<D> as IntoElement>::Element

Source

impl<D> IntoElement for Select<D>

Source

type Element = ViewElement<Select<D>>

Source

fn into_element(self) -> <Select<D> as IntoElement>::Element

Source

impl<E> IntoElement for ContextMenu<E>
where E: ParentElement + Styled + IntoElement + 'static,

Source

impl<E> IntoElement for Scrollable<E>

Source

impl<E> IntoElement for Sidebar<E>
where E: SidebarItem + 'static,

Source

type Element = ViewElement<Sidebar<E>>

Source

fn into_element(self) -> <Sidebar<E> as IntoElement>::Element

Source

impl<H> IntoElement for ScrollableMask<H>

Source

impl<T, B, V> IntoElement for BarChart<T, B, V>
where T: 'static, B: Eq + Hash + Into<SharedString> + 'static, V: Copy + PartialOrd + Num + ToPrimitive + Sealed + 'static,

Source

type Element = BarChart<T, B, V>

Source

fn into_element(self) -> <BarChart<T, B, V> as IntoElement>::Element

Source

impl<T, X, Y> IntoElement for AreaChart<T, X, Y>
where T: 'static, X: Clone + PartialEq + Into<SharedString> + 'static, Y: Clone + Copy + PartialOrd + Num + ToPrimitive + Sealed + 'static,

Source

impl<T, X, Y> IntoElement for CandlestickChart<T, X, Y>
where T: 'static, X: Eq + Hash + Into<SharedString> + 'static, Y: Copy + PartialOrd + Num + ToPrimitive + Sealed + 'static,

Source

impl<T, X, Y> IntoElement for LineChart<T, X, Y>
where T: 'static, X: PartialEq + Into<SharedString> + 'static, Y: Copy + PartialOrd + Num + ToPrimitive + Sealed + 'static,

Source

impl<T, Y> IntoElement for RadarChart<T, Y>
where T: 'static, Y: Clone + Copy + PartialOrd + Num + ToPrimitive + Sealed + 'static,

Source

impl<T> IntoElement for PieChart<T>
where T: 'static,

Source

impl<T> IntoElement for SankeyChart<T>
where T: 'static,

Implementors

Source

impl IntoElement for Anchored

Source

impl IntoElement for AnyElement

Source

impl IntoElement for AnyView

Source

type Element = ViewElement<AnyView>

Source

impl IntoElement for ContainerQuery

Source

impl IntoElement for Deferred

Source

impl IntoElement for Div

Source

impl IntoElement for Empty

Source

impl IntoElement for ImageCacheElement

Source

impl IntoElement for Img

Source

impl IntoElement for InteractiveText

Source

impl IntoElement for gpui_kit::List

Source

impl IntoElement for SharedString

Source

impl IntoElement for StyledText

Source

impl IntoElement for Surface

Source

impl IntoElement for Svg

Source

impl IntoElement for gpui_kit::Text

Source

impl IntoElement for UniformList

Source

impl<E> IntoElement for AnimationElement<E>
where E: IntoElement + 'static,

Source

impl<E> IntoElement for SpringAnimationElement<E>
where E: IntoElement + 'static,

Source

impl<E> IntoElement for Stateful<E>
where E: Element,

Source

impl<T> IntoElement for Canvas<T>
where T: 'static,

Source

impl<V> IntoElement for Entity<V>
where V: 'static + Render,

Source

type Element = ViewElement<Entity<V>>