pub fn dialog_arrival(theme: &Theme) -> MotionSpecExpand description
How a modal arrives when it should arrive with weight: on the smooth spring, which keeps moving after a curve of the same length has stopped.
pub fn dialog_arrival(theme: &Theme) -> MotionSpecHow a modal arrives when it should arrive with weight: on the smooth spring, which keeps moving after a curve of the same length has stopped.